@@ -2011,17 +2011,18 @@ ePhone	= '#8888FF'		# Extra class phone
 # ARRL band plan special frequencies
 Data	= '#FF9900'
 DxData	= '#CC6600'
-RTTY	= '#FF9900'
+RTTY	= '#DA5529'
 SSTV	= '#FFFF00'
 AM		= '#00FF00'
 Packet	= '#00FFFF'
-Beacons	= '#66FF66'
+Beacons	= '#6FAECA'
 Satellite	= '#22AA88'
 Repeater	= '#AA00FF'	# Repeater outputs
 RepInput	= '#AA88FF'	# Repeater inputs
-Simplex	= '#00FF44'
-Special	= 'hot pink'
+Simplex	= '#00BEFF'
+Special	= '#FF69B4'
 Other	= '#888888'
+RxOnly	= '#AAAAAA'
 # Colors start at the indicated frequency and continue until the
 # next frequency.  The special color "None" turns off color.
 #
@@ -2043,11 +2044,11 @@ BandPlan = [
   #[ 400000, AM], [ 450000, Packet], [ 500000, Beacons], [ 550000, Satellite], [ 600000, Repeater], [ 650000, RepInput], [ 700000, Simplex],
   #[ 750000, Other], [ 800000, Special], [ 850000, None],
   # 137k
-  [  130000, Data],
-  [  150000, None],
+  [  135700, Data],
+  [  137800, None],
   # 500k
-  [  490000, Data],
-  [  510000, None],
+  [  472000, Data],
+  [  479000, None],
   # 160 meters
   [ 1800000, Data],
   [ 1809000, Other],
@@ -2220,11 +2221,15 @@ BandPlan = [
   [10500000000, None],
   ]
 
+# List of all bands in order of frequency:
+BandList = [ '137k', '500k', '160', '80', '60', '40', '30', '20', '17', '15', '12', '10', '6', '4', '2',
+             '1.25', '70cm' , '33cm', '23cm', '13cm', '9cm', '5cm', '3cm']
+
 ## BandEdge 	Band Edge, dict
 # For each band, this dictionary gives the lower and upper band edges.  Frequencies
 # outside these limits will not be remembered as the last frequency in the band.
 BandEdge = {
-	'137k':( 136000,   138000),	'500k':( 400000,   600000),
+	'137k':( 135700,   137800),	'500k':( 472000,   479000),
 	'160':( 1800000,  2000000),	'80' :( 3500000,  4000000),
 	'60' :( 5300000,  5430000),	'40' :( 7000000,  7300000),
 	'30' :(10100000, 10150000),	'20' :(14000000, 14350000),	
